import request from '@/utils/request'

// 查询列表教育培训计划
export function listPlan(query) {
  return request({
    url: '/core/plan/list',
    method: 'get',
    params: query
  })
}

// 查询详细教育培训计划
export function getPlan(id) {
  return request({
    url: '/core/plan/' + id,
    method: 'get'
  })
}

// 新增教育培训计划
export function addPlan(data) {
  return request({
    url: '/core/plan',
    method: 'post',
    data: data
  })
}

// 修改教育培训计划
export function updatePlan(data) {
  return request({
    url: '/core/plan',
    method: 'put',
    data: data
  })
}

// 删除教育培训计划
export function delPlan(id) {
  return request({
    url: '/core/plan/' + id,
    method: 'delete'
  })
}

//获取教育培训计划角色列表
export function listPlanRole(query) {
  return request({
    url: '/core/plan/role/list',
    method: 'get',
    params: query
  })
}

//获取教育培训计划角色列表
export function roleList(query) {
  console.log("queryquery",query)
  return request({
    url: '/system/role/all',
    method: 'get',
    params: {
      orgType: query
    }
  })
}

//下发计划
export function publishPlan(id) {
  return request({
    url: '/core/plan/publish/' + id,
    method: 'get'
  })
}

